@@ -4,7 +4,7 @@ import ctypes, logging, os.path, getopt, sys, subprocess
 from fcntl import ioctl
 
 ghurl = 'https://github.com/soyersoyer/cameractrls'
-version = 'v0.4.12'
+version = 'v0.4.14'
 
 
 v4ldirs = {
@@ -1101,7 +1101,12 @@ LOGITECH_HW_CONTROL_LED1_FREQUENCY_OFFSET = 2
 # Logitech motor control v1 GUID 63610682-5070-49ab-b8cc-b3855e8d2256
 LOGITECH_MOTOR_CONTROL_V1_GUID = b'\x82\x06\x61\x63\x70\x50\xab\x49\xb8\xcc\xb3\x85\x5e\x8d\x22\x56'
 
-LOGITECH_MOTOR_CONTROL_FOCUS_DEV_MATCH = ['046d:0809', '046d:0990', '046d:0991', '046d:0994']
+LOGITECH_MOTOR_CONTROL_FOCUS_DEV_MATCH = [
+    '046d:0809', # Webcam Pro 9000
+    '046d:0990', # QuickCam Pro 9000
+    '046d:0991', # QuickCam Pro for Notebooks
+    '046d:0994', # QuickCam Orbit/Sphere AF
+]
 LOGITECH_MOTOR_CONTROL_FOCUS_SEL = 0x03
 LOGITECH_MOTOR_CONTROL_FOCUS_LEN = 6
 
@@ -1111,7 +1116,11 @@ LOGITECH_MOTOR_CONTROL_FOCUS_DESC = 'Allows the control of focus motor movements
 # Logitech BRIO GUID 49e40215-f434-47fe-b158-0e885023e51b
 LOGITECH_BRIO_GUID = b'\x15\x02\xe4\x49\x34\xf4\xfe\x47\xb1\x58\x0e\x88\x50\x23\xe5\x1b'
 
-LOGITECH_BRIO_FOV_DEV_MATCH = ['046d:085e']
+LOGITECH_BRIO_FOV_DEV_MATCH = [
+    '046d:085e', # Brio
+    '046d:0943', # Brio 500
+    '046d:086b', # Brio 4K Stream Edition
+]
 LOGITECH_BRIO_FOV_SEL = 0x05
 LOGITECH_BRIO_FOV_LEN = 1
 LOGITECH_BRIO_FOV_OFFSET = 0
@@ -1439,7 +1448,7 @@ class V4L2Ctrls:
                 ctrl_type = V4L2Ctrls.to_type.get(qctrl.type)
                 if ctrl_type == 'integer' and qctrl.minimum == 0 and qctrl.maximum == 1 and qctrl.step == 1:
                     ctrl_type = 'boolean'
-                
+
                 if ctrl_type != 'button':
                     try:
                         ctrl = v4l2_control(qctrl.id)
